<!-- Copyright 2023 Ross J. Duff MSc 
   The copyright holder licenses this file
   to you under the Apache License, Version 2.0 (the
   "License"); you may not use this file except in compliance
   with the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing,
   software distributed under the License is distributed on an
   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
   KIND, either express or implied.  See the License for the
   specific language governing permissions and limitations
   under the License. -->
# Changelog

<!--next-version-placeholder-->

## v0.0.26 (2023-08-19)

### Fix

* 🔧: Added mypy to optional-dependencies and requirements. ([`ba78c65`](https://github.com/rjdbcm/ozi/commit/ba78c65ae0b2b9444973d3485d6d24f53314ebc5))
* 🔧(ozi/scripts/meson.build): Add sync_pkg_readme.py. ([`d32bac9`](https://github.com/rjdbcm/ozi/commit/d32bac9718502e8218302a3e962ee5dae249c065))
* 🔧🎨(meson.build): Move code out of blastpipe and format. ([`6f4a0d2`](https://github.com/rjdbcm/ozi/commit/6f4a0d2765350008882fd6fbd88935e73efd5885))
* 🔧(pyproject.toml:tool.semantic_release): Update to target standard 0.1 milestone. ([`06286da`](https://github.com/rjdbcm/ozi/commit/06286dad75f3d0c3ef0cd196acd827b50f2e4e55))

### Other

* :pencil: Revert Version. ([`8d37ca7`](https://github.com/rjdbcm/ozi/commit/8d37ca7ab25614bca8fe6f68763e1980ed07ce89))
* :pencil: commit changelog during release. ([`e646d0b`](https://github.com/rjdbcm/ozi/commit/e646d0bc8377635520eddc23bb46e4da2583c540))
* :loud_sound: Added release changes and updated PKG-INFO. ([`bbfd15a`](https://github.com/rjdbcm/ozi/commit/bbfd15a39704c2934a3ee86bd44d98866801adb0))
* :pencil: fix version. ([`7ef2a05`](https://github.com/rjdbcm/ozi/commit/7ef2a05cfd70f74d33418d706b5a1e0df518da0b))
* :pencil: remove commit ammend. ([`083284e`](https://github.com/rjdbcm/ozi/commit/083284e09ec6feabd5213b631233b0260ca93325))
* :pencil:(pyproject.toml): --noedit should be --no-verify. ([`d002a1f`](https://github.com/rjdbcm/ozi/commit/d002a1f2a312e644822b7030887d50aa819cf7c6))
* :loud_sound: Added release changes and updated PKG-INFO. ([`6a5d7bb`](https://github.com/rjdbcm/ozi/commit/6a5d7bbdef9ac149dbe3098c766d2e1d615f2b7f))
* 🚧(meson.build): Commented out migrated install summary. ([`54d31c9`](https://github.com/rjdbcm/ozi/commit/54d31c99156019b4e408587a8978b5b0a6832ad0))
* Remove unecessary license header ([`4b09e8b`](https://github.com/rjdbcm/ozi/commit/4b09e8bd097c4005b07c22796e82069412ed9458))
* 🔨(meson.options): add mypy to lint utilities. ([`bee2247`](https://github.com/rjdbcm/ozi/commit/bee2247ae33974885faa57db4a10550686ff9d0f))
* FIX: potential CWE-23. ([`620ef68`](https://github.com/rjdbcm/ozi/commit/620ef68907b5d7a00bdcc8613e161fcc70ed9514))
* FIX: CWE-23 ([`d0036fc`](https://github.com/rjdbcm/ozi/commit/d0036fc4c91336fca41e9275e0ae1b3c6a8f7e67))
* 🔊: Add 0.0.25 changes. ([`10c0096`](https://github.com/rjdbcm/ozi/commit/10c0096d00a5743cfa036f79f94c2c8b6ead5d13))
* PKG-INFO Updated ([`e8b8e71`](https://github.com/rjdbcm/ozi/commit/e8b8e71fdb4df3c2f6c9f0cf896fc6145eb4b5e1))

## v0.0.25 (2023-08-05)

### Fix

* 🍱(ozi/assets): Restructured assets folder. ([`7a09768`](https://github.com/rjdbcm/ozi/commit/7a097680f940c4190b705c590ce08125f13a1c99))

### Other

* 👷(meson.build): Check PKG-INFO synced to pyproject. ([`515d4e8`](https://github.com/rjdbcm/ozi/commit/515d4e835395695400b1d3e358502eec53d8e550))
* 🔥 Migrate docs to [OZI.docs](https://github.com/rjdbcm/ozi.docs). ([`b3ff172`](https://github.com/rjdbcm/ozi/commit/b3ff172fc79b942344c498c1a7c6bdf34b44df81))
* 🔊(v0.0.24) ([`19c20f6`](https://github.com/rjdbcm/ozi/commit/19c20f6d4e3b4f6708c1b1bd9cb7dea3d567d1a4))
* PKG-INFO Updated ([`167694d`](https://github.com/rjdbcm/ozi/commit/167694d1d78f9b40a3b65f57466e389a84c040d0))

## v0.0.24 (2023-07-12)

### Fix

* 🔧(project.optional-dependencies): add lint plugins. ([`7453005`](https://github.com/rjdbcm/ozi/commit/7453005e9732d8d8cbb201005f402b12c89e9907))
* 🔧(black): add ``-S`` to skip string normalization. ([`76d6358`](https://github.com/rjdbcm/ozi/commit/76d6358f07f221659cca7ac6b86028f168baa2bd))
* 🔧(flake8): tidy-imports ban relative beyond sibling. ([`7dbde5e`](https://github.com/rjdbcm/ozi/commit/7dbde5e2c441a37b6ba9ede37a7196aad4de2ca7))
* 📌(project): Set pins. ([`347ed85`](https://github.com/rjdbcm/ozi/commit/347ed854011570c2c0633b9564e023d964201a99))
* 🚑️(Safety): Mitigation for CVE-2022-40898. ([`380e6c0`](https://github.com/rjdbcm/ozi/commit/380e6c07ecf8efe98ae2d315d2ee9fb316292db6))
* 🚑️(Safety): mitigation for CVE-2022-40897. ([`7d3d50f`](https://github.com/rjdbcm/ozi/commit/7d3d50f54cf3e157886f813adf58c4ff38060534))

### Other

* 🙈: add blastpipe to gitignore ([`d0130ba`](https://github.com/rjdbcm/ozi/commit/d0130ba81d10161cb6f4e4749402b3281e0f43f5))
* 🙈: add subprojects/dev.wrap. ([`1225f5b`](https://github.com/rjdbcm/ozi/commit/1225f5b5023d1fe7ac18d34de7c35d42a55c7e74))
* Merge branch 'main' of https://github.com/rjdbcm/ozi ([`2375cb4`](https://github.com/rjdbcm/ozi/commit/2375cb40d666c775c3bca411e1d75d0cb6a1b974))
* 📝(lint): update list of flake8 plugins. ([`f27ba85`](https://github.com/rjdbcm/ozi/commit/f27ba8551f6239bc44017c16f0ac74924cac3871))
* Update README.rst ([`8d7d0a6`](https://github.com/rjdbcm/ozi/commit/8d7d0a638a13e89ebfec7aefbf64a6623228188a))
* Add changes. ([`991d09a`](https://github.com/rjdbcm/ozi/commit/991d09ad41e568318b4532f97e79ad83438660d2))
* PKG-INFO Updated ([`e4feee9`](https://github.com/rjdbcm/ozi/commit/e4feee97a6e7c6ce0eebd879c4770bbe9267ccaf))

## v0.0.23 (2023-07-05)

### Fix

* :pencil2: blastpipe.wrap provides blastpipe. ([`68f1897`](https://github.com/rjdbcm/ozi/commit/68f1897671398b9a52ca42f3df6a15192950eba1))
* :pencil2: ozi-bootstrap becomes ozi-blastpipe

## v0.0.21 (2023-07-01)
### Fix
* 🚑️(tox): correct meson build options. Now using ozi-bootstrap=enabled. ([`30712f5`](https://github.com/rjdbcm/ozi/commit/30712f5204cadbb5c218bccba47d44cd34af02ac))

### Other
* 🔨(meson.options): Added python version options. Formerly these were hardcoded. ([`98dc031`](https://github.com/rjdbcm/ozi/commit/98dc03107c9ea202d92ba599a9516b58e5c76496))
* :technologist:(README.rst): Added bugfix section. ([`d522338`](https://github.com/rjdbcm/ozi/commit/d522338daf72bea127a3636a4bc61bcd13b04f49))
* 🧑‍💻: Update issue templates ([`24a9834`](https://github.com/rjdbcm/ozi/commit/24a9834112253dbf08114d4fb71735253797a11d))
* 📝 README.rst: add OpenSSF badge. ([`334bdb9`](https://github.com/rjdbcm/ozi/commit/334bdb937133b0795cf34c9a8cf51895e3140985))
* 🧑‍💻 README.rst: Add Contributing section. ([`14b8b5a`](https://github.com/rjdbcm/ozi/commit/14b8b5a813d65d711227e8c6b44cdd7b66ff832e))
* 📝 README.rst: Remove hanging markdown. ([`e49d3a0`](https://github.com/rjdbcm/ozi/commit/e49d3a0b2462d3ba83c38397774d8e137a14489c))
* 📝 README.rst: Fix FOSSA badge. ([`08b31f7`](https://github.com/rjdbcm/ozi/commit/08b31f731306aaad06f771ea433b9738d968ec23))
* 📝README.rst: fix FOSSA badge. ([`b054f57`](https://github.com/rjdbcm/ozi/commit/b054f5757dbac829b0e5d49e4488665d5b7c9367))
* Merge pull request #1 from fossabot/add-license-scan-badge ([`392de25`](https://github.com/rjdbcm/ozi/commit/392de25c26136925f77ddb2a9ea898f2ab085c73))
* Add license scan report and status ([`3814fcb`](https://github.com/rjdbcm/ozi/commit/3814fcbcdff6622771c67f9a036b47b5c589b13c))
* 👷(semantic-release): use textual changelog sections. ([`730b7ec`](https://github.com/rjdbcm/ozi/commit/730b7ec62cef8fdc7ef15391d1f15f1903244732))
* 🔨(semantic-release): git clean -dfX run pre_commit. ([`12c8de4`](https://github.com/rjdbcm/ozi/commit/12c8de45a6c36a18bc2ac2e66ef9be0ab50c081c))
* 🔊 Update CHANGELOG.md ([`1f3bf64`](https://github.com/rjdbcm/ozi/commit/1f3bf645408da6373bf12b05565fa03e0f0d2367))
* PKG-INFO Updated ([`c1c04d9`](https://github.com/rjdbcm/ozi/commit/c1c04d9bd89823b9d8c48eb422c5bc6a8360e883))

## v0.0.20 (2023-06-24)
### Other
* 🔨 drop PKG-INFO from pre_commit. ([`39a908d`](https://github.com/rjdbcm/ozi/commit/39a908d39cc747a5c33082bddf833e9fe2b9075b))
* 🔨 fix stash strategy.. ([`a20807e`](https://github.com/rjdbcm/ozi/commit/a20807e23f3555b8306523cc3da8ebf84ef575f2))
* PKG-INFO Updated ([`5de6296`](https://github.com/rjdbcm/ozi/commit/5de6296f33c58f751c97551b9b69f1f786c04409))

## v0.0.19 (2023-06-24)
### Other
* 🔨 stash after push release. ([`4169813`](https://github.com/rjdbcm/ozi/commit/4169813270f1e6783da08a914904b53776b3b49c))

## v0.0.18 (2023-06-24)
### Other
* 🔨 turn back on repo build. ([`4137e1e`](https://github.com/rjdbcm/ozi/commit/4137e1e2822dfce5eb0d47ac23519515422181db))

## v0.0.17 (2023-06-24)
### Other
* 🔊 Add changes for 0.0.16. ([`62e9641`](https://github.com/rjdbcm/ozi/commit/62e9641e4e0505e664449110d0a46b5e3a1f794f))

## v0.0.16 (2023-06-24)
### Other
* 🔊 add 0.0.16 changes. ([`c765e65`](https://github.com/rjdbcm/ozi/commit/c765e6545bbdacde2a76021e9311f3cf334e7065))
* 🔥 git rm -r --cached subprojects.dev ([`26590cc`](https://github.com/rjdbcm/ozi/commit/26590cc76e5adf543f5231d89279c8dd1c9cefb1))
* Add gitignore. ([`bf295f4`](https://github.com/rjdbcm/ozi/commit/bf295f4ad8b133cbe98a987ec09bd7bee3572428))
* 🔨 Just stash PKG-INFO. ([`40db643`](https://github.com/rjdbcm/ozi/commit/40db6433be6f26b802a4fc4b85393cf42b9c2131))
* PKG-INFO Updated ([`0916ffd`](https://github.com/rjdbcm/ozi/commit/0916ffd48343b54474bde97d77d52f32fd7b712c))
